<!DOCTYPE html>{% load i18n %}
<html lang="{{ LANGUAGE_CODE|default:"en" }}">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
    <meta http-equiv="content-language" content="{{ LANGUAGE_CODE|default:"en" }}" />
    <meta name="description" content="{% block page_description %}{% endblock page_description %}" />
    <meta name="robots" content="{% block robots_content %}all{% endblock robots_content %}" />
    <meta http-equiv="keywords" content="{% trans "glossario" %},{% block keywords %}{% endblock keywords %}{% trans "termini" %}" />
    <title>{% block title %}{% if page_title %}{{ page_title }}{% else %}{% trans "Glossario" %}{% endif %}{% endblock title %}</title>
{#    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.6/css/bootstrap.min.css" integrity="sha384-1q8mTJOASx8j1Au+a5WDVnPi2lkFfwwEAa8hDDdjZlpLegxhjVME1fgjWPGmkzs7" crossorigin="anonymous">#}
    <link href="https://maxcdn.bootstrapcdn.com/bootswatch/3.3.6/lumen/bootstrap.min.css" rel="stylesheet" integrity="sha384-mvYjhBJXQ9VlNETV/xXShy849GsBHnKzVVudnMOcWUVM/6Nd2ksj8VNng5f8ylyX" crossorigin="anonymous">
    <style>
        body {padding-top: 50px}
        .main-content {position: relative}
{% comment %}
{% if glossary_columns %}
        div.glossary-list {-webkit-column-count: {{ glossary_columns }}; -moz-column-count: {{ glossary_columns }}; column-count: {{ glossary_columns }}}
{% endif %}
{% endcomment %}
        .affix {top: 80px;}
        .pagination {margin: 11px 0}
        .pagination-sm>li>a, .pagination-sm>li>span {
            padding: 5px 8px;
            font-size: 11px;
            line-height: 1.5;
        }
    </style>
{% block extrahead %}{% endblock extrahead %}
    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
      <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
</head>
<body>
    <nav class="navbar navbar-default navbar-fixed-top">
        <div class="container">
            <div class="navbar-header">
                <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navbar" aria-expanded="false" aria-controls="navbar">
                    <span class="sr-only">{% trans "Toggle navigation" %}</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
                <a class="navbar-brand" href="{% url "glossario" %}">{% trans "Glossario" %}</a>
            </div>
            <div id="navbar" class="collapse navbar-collapse">
{% include "glossario/index.html" %}
            </div>
        </div>
    </nav>

    <div class="container">
        <div class="row">
{% block main_content %}
            <div class="col-md-9 main-content" role="main">
{% block glossary-detail %}{% endblock glossary-detail %}
            </div>
{% if term_list %}
            <div class="col-md-3" role="complementary">
                <nav class="col-md-3 glossary-list hidden-print hidden-xs hidden-sm">
{% block glossary-terms %}{% include "glossario/terms_index.html" %}{% endblock glossary-terms %}
                </nav>
            <div>
{% endif %}
{% endblock main_content %}
        </div>
    </div>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.11.3/jquery.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.6/js/bootstrap.min.js" integrity="sha384-0mSbJDEHialfmuBBQP6A4Qrprq5OVfW37PRR3j5ELqxss1yVqOtnepnHVP9aJ7xS" crossorigin="anonymous"></script>
</body>
</html>
